@@ -1,7 +1,7 @@
 from django.http import HttpResponse
 from django.utils import simplejson
 from django.template.defaultfilters import slugify
-from django.shortcuts import render_to_response
+from django.shortcuts import render_to_response, render
 from django.conf import settings
 
 from helpers import get_model
@@ -96,4 +96,23 @@ def filter_json(request, model_str, field):
         if slugify(q) in slugify(obj_attr) and not obj.pk in exclude:
             data.append((obj.pk, obj.__unicode__(), obj_attr))
 
-    return HttpResponse(simplejson.dumps(data))
\ No newline at end of file
+    return HttpResponse(simplejson.dumps(data))
+
+
+def m2m_list_view(request, model_str):
+    pks = [int(pk) for pk in request.GET.get("q", "").split(",")]
+    Model = get_model(model_str)
+    objs = Model.objects.filter(pk__in=pks)
+
+    return render(request, "large_data_admin/m2m/list.html", {
+        "objs": objs,
+    })
+
+def m2m_remove_view(request, model_str):
+    pks = [int(pk) for pk in request.GET.get("q", "").split(",")]
+    Model = get_model(model_str)
+    objs = Model.objects.filter(pk__in=pks)
+
+    return render(request, "large_data_admin/m2m/remove.html", {
+        "objs": objs,
+    })
\ No newline at end of file
